Assorted spelling fixes.

Francois Gouget fgouget at free.fr
Tue Feb 20 08:57:10 CST 2007


---
 dlls/comctl32/tests/header.c   |    2 +-
 dlls/comctl32/tests/monthcal.c |    4 ++--
 dlls/d3d9/tests/visual.c       |    6 +++---
 dlls/ddraw/tests/refcount.c    |    2 +-
 dlls/setupapi/devinst.c        |    2 +-
 dlls/wined3d/context.c         |    4 ++--
 dlls/wined3d/state.c           |    2 +-
 dlls/wined3d/surface.c         |    8 ++++----
 dlls/wined3d/wined3d_private.h |    2 +-
 dlls/wininet/ftp.c             |    2 +-
 tools/winapi/winapi.pm         |    2 +-
 11 files changed, 18 insertions(+), 18 deletions(-)

diff --git a/dlls/comctl32/tests/header.c b/dlls/comctl32/tests/header.c
index 5f65f95..29ef9aa 100644
--- a/dlls/comctl32/tests/header.c
+++ b/dlls/comctl32/tests/header.c
@@ -520,7 +520,7 @@ static void test_hdm_getitemrect(void)
     expect(80, rect.right);
     expect(18, rect.bottom);
     retVal = SendMessage(hWndHeader, HDM_GETITEMRECT, 10, (LPARAM) &rect);
-    ok(retVal == 0, "Getting rect of non-existing item should return 0, got %d\n", retVal);
+    ok(retVal == 0, "Getting rect of nonexistent item should return 0, got %d\n", retVal);
 }
 
 static void test_hdm_layout (void)
diff --git a/dlls/comctl32/tests/monthcal.c b/dlls/comctl32/tests/monthcal.c
index 80829ce..6de5be8 100644
--- a/dlls/comctl32/tests/monthcal.c
+++ b/dlls/comctl32/tests/monthcal.c
@@ -237,7 +237,7 @@ static void test_monthcal_currDate(HWND hwnd)
     expect(st_original.wMinute, st_new.wMinute);
     expect(st_original.wSecond, st_new.wSecond);
 
-    /* lparam can not be NULL */
+    /* lparam cannot be NULL */
     res = SendMessage(hwnd, MCM_GETCURSEL, 0, (LPARAM) NULL);
     expect(0, res);
 }
@@ -258,7 +258,7 @@ static void test_monthcal_firstDay(HWND hwnd)
             res = SendMessage(hwnd, MCM_SETFIRSTDAYOFWEEK, 0, (LPARAM) 0);
             expect(fday, res);
         }else{
-            skip("Can not retrive first day of the week\n");
+            skip("Cannot retrieve first day of the week\n");
             SendMessage(hwnd, MCM_SETFIRSTDAYOFWEEK, 0, (LPARAM) 0);
         }
 
diff --git a/dlls/d3d9/tests/visual.c b/dlls/d3d9/tests/visual.c
index 40b8134..f5c15a0 100644
--- a/dlls/d3d9/tests/visual.c
+++ b/dlls/d3d9/tests/visual.c
@@ -20,8 +20,8 @@
 /* This test framework allows limited testing of rendering results. Things are rendered, shown on
  * the framebuffer, read back from there and compared to expected colors.
  *
- * However, neither d3d nor opengl is guaranted to be pixel exact, and thus the capability of this test
- * is rather limited. As a general guideline for adding tests, do not rely on corner pixels. Draw a big enought
+ * However, neither d3d nor opengl is guaranteed to be pixel exact, and thus the capability of this test
+ * is rather limited. As a general guideline for adding tests, do not rely on corner pixels. Draw a big enough
  * area which shows specific behavior(like a quad on the whole screen), and try to get resulting colos with
  * all bits set or unset in all channels(like pure red, green, blue, white, black). Hopefully everything that
  * causes visible results in games can be tested in a way that does not depend on pixel exactness
@@ -261,7 +261,7 @@ static void lighting_test(IDirect3DDevice9 *device)
     ok(hr == D3D_OK, "IDirect3DDevice9_SetRenderState returned %s\n", DXGetErrorString9(hr));
 
     /* Hack for a bug in d3d9: SetFVF creates a converted vertex declaration, with a circular refcount.
-     * This prevents the screen resulution from beeing restored correctly on device release. Unset the vdecl
+     * This prevents the screen resolution from being restored correctly on device release. Unset the vdecl
      */
     IDirect3DDevice9_SetVertexDeclaration(device, NULL);
 }
diff --git a/dlls/ddraw/tests/refcount.c b/dlls/ddraw/tests/refcount.c
index 11301d3..916e8f5 100644
--- a/dlls/ddraw/tests/refcount.c
+++ b/dlls/ddraw/tests/refcount.c
@@ -165,7 +165,7 @@ static void test_ddraw_objects(void)
     ok(ref == 1, "Got refcount %ld, expected 1\n", ref);
     IDirectDrawPalette_Release(palette);
 
-    /* Simmilar for surfaces */
+    /* Similar for surfaces */
     hr = IDirectDraw4_CreateSurface(DDraw4, &ddsd, &surface4, NULL);
     ok(hr == DD_OK, "CreateSurface returned %08x\n", hr);
     ref = getRefcount( (IUnknown *) DDraw4);
diff --git a/dlls/setupapi/devinst.c b/dlls/setupapi/devinst.c
index fbf6ded..14e155c 100644
--- a/dlls/setupapi/devinst.c
+++ b/dlls/setupapi/devinst.c
@@ -648,7 +648,7 @@ SetupDiCreateDeviceInfoListExA(const GUID *ClassGuid,
  *                 with this list.
  *   hwndParent [I] hwnd needed for interface related actions.
  *   MachineName [I] name of machine to create emtpy DeviceInfoSet list, if NULL
- *                   local regestry will be used.
+ *                   local registry will be used.
  *   Reserved [I] must be NULL
  *
  * RETURNS
diff --git a/dlls/wined3d/context.c b/dlls/wined3d/context.c
index 603ce49..ac2ca44 100644
--- a/dlls/wined3d/context.c
+++ b/dlls/wined3d/context.c
@@ -197,7 +197,7 @@ static GLXFBConfig* pbuffer_find_fbconfigs(
  *  This: Device to activate the context for
  *  target: Surface this context will render to
  *  display: X11 connection
- *  win: Taget window. NULL for a pbuffer
+ *  win: Target window. NULL for a pbuffer
  *
  *****************************************************************************/
 WineD3DContext *CreateContext(IWineD3DDeviceImpl *This, IWineD3DSurfaceImpl *target, Display *display, Window win) {
@@ -368,7 +368,7 @@ out:
  * Removes a context from the context manager. The opengl context is not
  * destroyed or unset. context is not a valid pointer after that call.
  *
- * Simmilar to the former call this isn't a performance critical function. A
+ * Similar to the former call this isn't a performance critical function. A
  * helper function for DestroyContext.
  *
  * Params:
diff --git a/dlls/wined3d/state.c b/dlls/wined3d/state.c
index f78720a..1a73b57 100644
--- a/dlls/wined3d/state.c
+++ b/dlls/wined3d/state.c
@@ -2839,7 +2839,7 @@ static void vertexdeclaration(DWORD state, IWineD3DStateBlockImpl *stateblock, W
         updateFog = TRUE;
     }
 
-    /* Reapply lighting if it is not sheduled for reapplication already */
+    /* Reapply lighting if it is not scheduled for reapplication already */
     if(!isStateDirty(context, STATE_RENDER(WINED3DRS_LIGHTING))) {
         state_lighting(STATE_RENDER(WINED3DRS_LIGHTING), stateblock, context);
     }
diff --git a/dlls/wined3d/wined3d_private.h b/dlls/wined3d/wined3d_private.h
index be8cd6e..e314fd1 100644
--- a/dlls/wined3d/wined3d_private.h
+++ b/dlls/wined3d/wined3d_private.h
@@ -560,7 +560,7 @@ typedef struct IWineD3DImpl
 
 extern const IWineD3DVtbl IWineD3D_Vtbl;
 
-/* TODO: setup some flags in the regestry to enable, disable pbuffer support
+/* TODO: setup some flags in the registry to enable, disable pbuffer support
 (since it will break quite a few things until contexts are managed properly!) */
 extern BOOL pbuffer_support;
 /* allocate one pbuffer per surface */
diff --git a/dlls/wininet/ftp.c b/dlls/wininet/ftp.c
index c106492..7fa0256 100644
--- a/dlls/wininet/ftp.c
+++ b/dlls/wininet/ftp.c
@@ -3420,7 +3420,7 @@ static DWORD FTP_SetResponseError(DWORD dwResponse)
 	case 451: /* Action aborted. Server error. */
 	case 452: /* Action not taken. Insufficient storage space on server. */
 	case 502: /* Command not implemented. */
-	case 503: /* Bad sequence of command. */
+	case 503: /* Bad sequence of commands. */
 	case 504: /* Command not implemented for that parameter. */
 	case 532: /* Need account for storing files */
 	case 551: /* Requested action aborted. Page type unknown */
diff --git a/tools/winapi/winapi.pm b/tools/winapi/winapi.pm
index eb85d08..5bf4ce6 100644
--- a/tools/winapi/winapi.pm
+++ b/tools/winapi/winapi.pm
@@ -385,7 +385,7 @@ sub parse_spec_file($$) {
 		    my $name4 = $name;
 		    $name4 =~ s/^(VxDCall)\d$/$1/;
 
-		    # FIXME: This special case is becuase of a very ugly kludge that should be fixed IMHO
+		    # FIXME: This special case is because of a very ugly kludge that should be fixed IMHO
 		    my $name5 = $name;
 		    $name5 =~ s/^(.*?16)_(.*?)$/$1_fn$2/;
 
diff --git a/dlls/wined3d/surface.c b/dlls/wined3d/surface.c
index 562adcd..00199c8 100644
--- a/dlls/wined3d/surface.c
+++ b/dlls/wined3d/surface.c
@@ -266,8 +266,8 @@ ULONG WINAPI IWineD3DSurfaceImpl_Release(IWineD3DSurface *iface) {
                     TRACE("Activating primary front buffer\n");
                     ActivateContext(device, swapchain->frontBuffer, CTXUSAGE_RESOURCELOAD);
                 } else {
-                    TRACE("Device is beeing destroyed, setting lastActiveRenderTarget = 0xdeadbabe\n");
-                    /* Implicit render target destroyed, that means the device is beeing destroyed
+                    TRACE("Device is being destroyed, setting lastActiveRenderTarget = 0xdeadbabe\n");
+                    /* Implicit render target destroyed, that means the device is being destroyed
                      * whatever we set here, it shouldn't matter
                      */
                     device->lastActiveRenderTarget = (IWineD3DSurface *) 0xdeadbabe;
@@ -760,7 +760,7 @@ static HRESULT WINAPI IWineD3DSurfaceImpl_LockRect(IWineD3DSurface *iface, WINED
 
         /* TODO: Make sure that *any* context is active for this thread. It is not important which context that is,
          * nor that is has any special setup(CTXUSAGE_LOADRESOURCE is fine), but the code below needs a context.
-         * A context is guaranted to be there in a single threaded environment, but not with multithreading
+         * A context is guaranteed to be there in a single threaded environment, but not with multithreading
          */
         if (0 != This->glDescription.textureName) {
             /* Now I have to copy thing bits back */
@@ -2802,7 +2802,7 @@ static HRESULT IWineD3DSurfaceImpl_BltOverride(IWineD3DSurfaceImpl *This, RECT *
         }
     }
 
-    /* Default: Fall back to the generic blt. Not an error, a TRACE is enought */
+    /* Default: Fall back to the generic blt. Not an error, a TRACE is enough */
     TRACE("Didn't find any usable render target setup for hw blit, falling back to software\n");
     return WINED3DERR_INVALIDCALL;
 }
-- 
1.4.4.4




More information about the wine-patches mailing list